PaymentService class

Constructors

PaymentService({required String apiKey, String host = _defaultHost, Client? client})

Properties

apiKey → String
Public API key used to authenticate with Conekta.
final
client → Client
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
The base URL for the Conekta API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encryptCardField(String plainText) → String
encryptCardField encrypts a card field using the public key.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendPayment(CardModel card, String locale) → Future<Map<String, dynamic>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited